# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_groundstation.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1b\x61ws/aws_groundstation.proto\x12\x1doak9.tython.aws.groundstation\x1a\x13shared/shared.proto\"\xba\x02\n\x06\x43onfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12=\n\x04tags\x18\x03 \x03(\x0b\x32/.oak9.tython.aws.groundstation.Config.TagsEntry\x12J\n\x0b\x63onfig_data\x18\x04 \x03(\x0b\x32\x35.oak9.tython.aws.groundstation.Config.ConfigDataEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x31\n\x0f\x43onfigDataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xe5\x01\n\rGroundStation\x12\x35\n\x06\x63onfig\x18\x01 \x03(\x0b\x32%.oak9.tython.aws.groundstation.Config\x12U\n\x17\x64\x61taflow_endpoint_group\x18\x02 \x03(\x0b\x32\x34.oak9.tython.aws.groundstation.DataflowEndpointGroup\x12\x46\n\x0fmission_profile\x18\x03 \x03(\x0b\x32-.oak9.tython.aws.groundstation.MissionProfile\"\xa1\x01\n$DataflowEndpointGroupSecurityDetails\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x12\n\nsubnet_ids\x18\x02 \x03(\t\x12\x1a\n\x12security_group_ids\x18\x03 \x03(\t\x12\x10\n\x08role_arn\x18\x04 \x01(\t\"y\n\"DataflowEndpointGroupSocketAddress\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04port\x18\x03 \x01(\x05\"\xdf\x01\n%DataflowEndpointGroupDataflowEndpoint\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12R\n\x07\x61\x64\x64ress\x18\x03 \x01(\x0b\x32\x41.oak9.tython.aws.groundstation.DataflowEndpointGroupSocketAddress\x12\x0e\n\x06status\x18\x04 \x01(\t\x12\x0b\n\x03mtu\x18\x05 \x01(\x05\"\x96\x02\n$DataflowEndpointGroupEndpointDetails\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12]\n\x10security_details\x18\x02 \x01(\x0b\x32\x43.oak9.tython.aws.groundstation.DataflowEndpointGroupSecurityDetails\x12V\n\x08\x65ndpoint\x18\x03 \x01(\x0b\x32\x44.oak9.tython.aws.groundstation.DataflowEndpointGroupDataflowEndpoint\"\xaa\x02\n\x15\x44\x61taflowEndpointGroup\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12]\n\x10\x65ndpoint_details\x18\x02 \x03(\x0b\x32\x43.oak9.tython.aws.groundstation.DataflowEndpointGroupEndpointDetails\x12L\n\x04tags\x18\x03 \x03(\x0b\x32>.oak9.tython.aws.groundstation.DataflowEndpointGroup.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"z\n\x1aMissionProfileDataflowEdge\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0e\n\x06source\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65stination\x18\x03 \x01(\t\"\xc3\x03\n\x0eMissionProfile\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12)\n!contact_pre_pass_duration_seconds\x18\x03 \x01(\x05\x12*\n\"contact_post_pass_duration_seconds\x18\x04 \x01(\x05\x12/\n\'minimum_viable_contact_duration_seconds\x18\x05 \x01(\x05\x12Q\n\x0e\x64\x61taflow_edges\x18\x06 \x03(\x0b\x32\x39.oak9.tython.aws.groundstation.MissionProfileDataflowEdge\x12\x1b\n\x13tracking_config_arn\x18\x07 \x01(\t\x12\x45\n\x04tags\x18\x08 \x03(\x0b\x32\x37.oak9.tython.aws.groundstation.MissionProfile.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_groundstation_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _CONFIG_TAGSENTRY._options = None
  _CONFIG_TAGSENTRY._serialized_options = b'8\001'
  _CONFIG_CONFIGDATAENTRY._options = None
  _CONFIG_CONFIGDATAENTRY._serialized_options = b'8\001'
  _DATAFLOWENDPOINTGROUP_TAGSENTRY._options = None
  _DATAFLOWENDPOINTGROUP_TAGSENTRY._serialized_options = b'8\001'
  _MISSIONPROFILE_TAGSENTRY._options = None
  _MISSIONPROFILE_TAGSENTRY._serialized_options = b'8\001'
  _CONFIG._serialized_start=84
  _CONFIG._serialized_end=398
  _CONFIG_TAGSENTRY._serialized_start=304
  _CONFIG_TAGSENTRY._serialized_end=347
  _CONFIG_CONFIGDATAENTRY._serialized_start=349
  _CONFIG_CONFIGDATAENTRY._serialized_end=398
  _GROUNDSTATION._serialized_start=401
  _GROUNDSTATION._serialized_end=630
  _DATAFLOWENDPOINTGROUPSECURITYDETAILS._serialized_start=633
  _DATAFLOWENDPOINTGROUPSECURITYDETAILS._serialized_end=794
  _DATAFLOWENDPOINTGROUPSOCKETADDRESS._serialized_start=796
  _DATAFLOWENDPOINTGROUPSOCKETADDRESS._serialized_end=917
  _DATAFLOWENDPOINTGROUPDATAFLOWENDPOINT._serialized_start=920
  _DATAFLOWENDPOINTGROUPDATAFLOWENDPOINT._serialized_end=1143
  _DATAFLOWENDPOINTGROUPENDPOINTDETAILS._serialized_start=1146
  _DATAFLOWENDPOINTGROUPENDPOINTDETAILS._serialized_end=1424
  _DATAFLOWENDPOINTGROUP._serialized_start=1427
  _DATAFLOWENDPOINTGROUP._serialized_end=1725
  _DATAFLOWENDPOINTGROUP_TAGSENTRY._serialized_start=304
  _DATAFLOWENDPOINTGROUP_TAGSENTRY._serialized_end=347
  _MISSIONPROFILEDATAFLOWEDGE._serialized_start=1727
  _MISSIONPROFILEDATAFLOWEDGE._serialized_end=1849
  _MISSIONPROFILE._serialized_start=1852
  _MISSIONPROFILE._serialized_end=2303
  _MISSIONPROFILE_TAGSENTRY._serialized_start=304
  _MISSIONPROFILE_TAGSENTRY._serialized_end=347
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_kinesisanalyticsv2.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n aws/aws_kinesisanalyticsv2.proto\x12\"oak9.tython.aws.kinesisanalyticsv2\x1a\x13shared/shared.proto\"\x95\x01\n\x1c\x41pplicationS3ContentLocation\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x12\n\nbucket_arn\x18\x02 \x01(\t\x12\x10\n\x08\x66ile_key\x18\x03 \x01(\t\x12\x16\n\x0eobject_version\x18\x04 \x01(\t\"\xe0\x01\n\x16\x41pplicationCodeContent\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x18\n\x10zip_file_content\x18\x02 \x01(\t\x12]\n\x13s3_content_location\x18\x03 \x01(\x0b\x32@.oak9.tython.aws.kinesisanalyticsv2.ApplicationS3ContentLocation\x12\x14\n\x0ctext_content\x18\x04 \x01(\t\"\xcf\x01\n\'ApplicationApplicationCodeConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x19\n\x11\x63ode_content_type\x18\x02 \x01(\t\x12P\n\x0c\x63ode_content\x18\x03 \x01(\x0b\x32:.oak9.tython.aws.kinesisanalyticsv2.ApplicationCodeContent\"\x87\x02\n\x18\x41pplicationPropertyGroup\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x63\n\x0cproperty_map\x18\x02 \x03(\x0b\x32M.oak9.tython.aws.kinesisanalyticsv2.ApplicationPropertyGroup.PropertyMapEntry\x12\x19\n\x11property_group_id\x18\x03 \x01(\t\x1a\x32\n\x10PropertyMapEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xb2\x01\n ApplicationEnvironmentProperties\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12U\n\x0fproperty_groups\x18\x02 \x03(\x0b\x32<.oak9.tython.aws.kinesisanalyticsv2.ApplicationPropertyGroup\"\xdc\x01\n\"ApplicationCheckpointConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1a\n\x12\x63onfiguration_type\x18\x02 \x01(\t\x12\x1b\n\x13\x63heckpoint_interval\x18\x03 \x01(\x05\x12%\n\x1dmin_pause_between_checkpoints\x18\x04 \x01(\x05\x12\x1d\n\x15\x63heckpointing_enabled\x18\x05 \x01(\x08\"\xcc\x01\n#ApplicationParallelismConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1a\n\x12\x63onfiguration_type\x18\x02 \x01(\t\x12\x1d\n\x15parallelism_per_k_p_u\x18\x03 \x01(\x05\x12\x1c\n\x14\x61uto_scaling_enabled\x18\x04 \x01(\x08\x12\x13\n\x0bparallelism\x18\x05 \x01(\x05\"\xa3\x01\n\"ApplicationMonitoringConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1a\n\x12\x63onfiguration_type\x18\x02 \x01(\t\x12\x15\n\rmetrics_level\x18\x03 \x01(\t\x12\x11\n\tlog_level\x18\x04 \x01(\t\"\xa3\x03\n(ApplicationFlinkApplicationConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12h\n\x18\x63heckpoint_configuration\x18\x02 \x01(\x0b\x32\x46.oak9.tython.aws.kinesisanalyticsv2.ApplicationCheckpointConfiguration\x12j\n\x19parallelism_configuration\x18\x03 \x01(\x0b\x32G.oak9.tython.aws.kinesisanalyticsv2.ApplicationParallelismConfiguration\x12h\n\x18monitoring_configuration\x18\x04 \x01(\x0b\x32\x46.oak9.tython.aws.kinesisanalyticsv2.ApplicationMonitoringConfiguration\"\x83\x01\n\x17\x41pplicationRecordColumn\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0f\n\x07mapping\x18\x02 \x01(\t\x12\x10\n\x08sql_type\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\"t\n ApplicationJSONMappingParameters\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x17\n\x0frecord_row_path\x18\x02 \x01(\t\"\x99\x01\n\x1f\x41pplicationCSVMappingParameters\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1c\n\x14record_row_delimiter\x18\x02 \x01(\t\x12\x1f\n\x17record_column_delimiter\x18\x03 \x01(\t\"\xa4\x02\n\x1c\x41pplicationMappingParameters\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x65\n\x17json_mapping_parameters\x18\x02 \x01(\x0b\x32\x44.oak9.tython.aws.kinesisanalyticsv2.ApplicationJSONMappingParameters\x12\x64\n\x17\x63s_v_mapping_parameters\x18\x03 \x01(\x0b\x32\x43.oak9.tython.aws.kinesisanalyticsv2.ApplicationCSVMappingParameters\"\xcc\x01\n\x17\x41pplicationRecordFormat\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\\\n\x12mapping_parameters\x18\x02 \x01(\x0b\x32@.oak9.tython.aws.kinesisanalyticsv2.ApplicationMappingParameters\x12\x1a\n\x12record_format_type\x18\x03 \x01(\t\"\x93\x02\n\x16\x41pplicationInputSchema\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x17\n\x0frecord_encoding\x18\x02 \x01(\t\x12S\n\x0erecord_columns\x18\x03 \x03(\x0b\x32;.oak9.tython.aws.kinesisanalyticsv2.ApplicationRecordColumn\x12R\n\rrecord_format\x18\x04 \x01(\x0b\x32;.oak9.tython.aws.kinesisanalyticsv2.ApplicationRecordFormat\"o\n\x1e\x41pplicationKinesisStreamsInput\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x14\n\x0cresource_arn\x18\x02 \x01(\t\"p\n\x1f\x41pplicationKinesisFirehoseInput\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x14\n\x0cresource_arn\x18\x02 \x01(\t\"p\n\x1f\x41pplicationInputLambdaProcessor\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x14\n\x0cresource_arn\x18\x02 \x01(\t\"\xc7\x01\n\'ApplicationInputProcessingConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x63\n\x16input_lambda_processor\x18\x02 \x01(\x0b\x32\x43.oak9.tython.aws.kinesisanalyticsv2.ApplicationInputLambdaProcessor\"e\n\x1b\x41pplicationInputParallelism\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\r\n\x05\x63ount\x18\x02 \x01(\x05\"\xcb\x04\n\x10\x41pplicationInput\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0bname_prefix\x18\x02 \x01(\t\x12P\n\x0cinput_schema\x18\x03 \x01(\x0b\x32:.oak9.tython.aws.kinesisanalyticsv2.ApplicationInputSchema\x12\x61\n\x15kinesis_streams_input\x18\x04 \x01(\x0b\x32\x42.oak9.tython.aws.kinesisanalyticsv2.ApplicationKinesisStreamsInput\x12\x63\n\x16kinesis_firehose_input\x18\x05 \x01(\x0b\x32\x43.oak9.tython.aws.kinesisanalyticsv2.ApplicationKinesisFirehoseInput\x12s\n\x1einput_processing_configuration\x18\x06 \x01(\x0b\x32K.oak9.tython.aws.kinesisanalyticsv2.ApplicationInputProcessingConfiguration\x12Z\n\x11input_parallelism\x18\x07 \x01(\x0b\x32?.oak9.tython.aws.kinesisanalyticsv2.ApplicationInputParallelism\"\xa7\x01\n&ApplicationSqlApplicationConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x44\n\x06inputs\x18\x02 \x03(\x0b\x32\x34.oak9.tython.aws.kinesisanalyticsv2.ApplicationInput\"\x81\x01\n+ApplicationApplicationSnapshotConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x19\n\x11snapshots_enabled\x18\x02 \x01(\x08\"\xa0\x05\n#ApplicationApplicationConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12s\n\x1e\x61pplication_code_configuration\x18\x02 \x01(\x0b\x32K.oak9.tython.aws.kinesisanalyticsv2.ApplicationApplicationCodeConfiguration\x12\x64\n\x16\x65nvironment_properties\x18\x03 \x01(\x0b\x32\x44.oak9.tython.aws.kinesisanalyticsv2.ApplicationEnvironmentProperties\x12u\n\x1f\x66link_application_configuration\x18\x04 \x01(\x0b\x32L.oak9.tython.aws.kinesisanalyticsv2.ApplicationFlinkApplicationConfiguration\x12q\n\x1dsql_application_configuration\x18\x05 \x01(\x0b\x32J.oak9.tython.aws.kinesisanalyticsv2.ApplicationSqlApplicationConfiguration\x12{\n\"application_snapshot_configuration\x18\x06 \x01(\x0b\x32O.oak9.tython.aws.kinesisanalyticsv2.ApplicationApplicationSnapshotConfiguration\"\xa0\x03\n\x0b\x41pplication\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x18\n\x10\x61pplication_name\x18\x02 \x01(\t\x12\x1b\n\x13runtime_environment\x18\x03 \x01(\t\x12j\n\x19\x61pplication_configuration\x18\x04 \x01(\x0b\x32G.oak9.tython.aws.kinesisanalyticsv2.ApplicationApplicationConfiguration\x12\x1f\n\x17\x61pplication_description\x18\x05 \x01(\t\x12G\n\x04tags\x18\x06 \x03(\x0b\x32\x39.oak9.tython.aws.kinesisanalyticsv2.Application.TagsEntry\x12\x1e\n\x16service_execution_role\x18\x07 \x01(\t\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x94\x03\n\x12KinesisAnalyticsV2\x12\x44\n\x0b\x61pplication\x18\x01 \x03(\x0b\x32/.oak9.tython.aws.kinesisanalyticsv2.Application\x12v\n&application_cloud_watch_logging_option\x18\x02 \x03(\x0b\x32\x46.oak9.tython.aws.kinesisanalyticsv2.ApplicationCloudWatchLoggingOption\x12Q\n\x12\x61pplication_output\x18\x03 \x03(\x0b\x32\x35.oak9.tython.aws.kinesisanalyticsv2.ApplicationOutput\x12m\n!application_reference_data_source\x18\x04 \x03(\x0b\x32\x42.oak9.tython.aws.kinesisanalyticsv2.ApplicationReferenceDataSource\"\x8c\x01\n9ApplicationCloudWatchLoggingOptionCloudWatchLoggingOption\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x16\n\x0elog_stream_arn\x18\x02 \x01(\t\"\xfb\x01\n\"ApplicationCloudWatchLoggingOption\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x18\n\x10\x61pplication_name\x18\x02 \x01(\t\x12\x81\x01\n\x1a\x63loud_watch_logging_option\x18\x03 \x01(\x0b\x32].oak9.tython.aws.kinesisanalyticsv2.ApplicationCloudWatchLoggingOptionCloudWatchLoggingOption\"y\n\"ApplicationOutputDestinationSchema\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1a\n\x12record_format_type\x18\x02 \x01(\t\"n\n\x1d\x41pplicationOutputLambdaOutput\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x14\n\x0cresource_arn\x18\x02 \x01(\t\"w\n&ApplicationOutputKinesisFirehoseOutput\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x14\n\x0cresource_arn\x18\x02 \x01(\t\"v\n%ApplicationOutputKinesisStreamsOutput\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x14\n\x0cresource_arn\x18\x02 \x01(\t\"\xf6\x03\n\x17\x41pplicationOutputOutput\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x62\n\x12\x64\x65stination_schema\x18\x02 \x01(\x0b\x32\x46.oak9.tython.aws.kinesisanalyticsv2.ApplicationOutputDestinationSchema\x12X\n\rlambda_output\x18\x03 \x01(\x0b\x32\x41.oak9.tython.aws.kinesisanalyticsv2.ApplicationOutputLambdaOutput\x12k\n\x17kinesis_firehose_output\x18\x04 \x01(\x0b\x32J.oak9.tython.aws.kinesisanalyticsv2.ApplicationOutputKinesisFirehoseOutput\x12i\n\x16kinesis_streams_output\x18\x05 \x01(\x0b\x32I.oak9.tython.aws.kinesisanalyticsv2.ApplicationOutputKinesisStreamsOutput\x12\x0c\n\x04name\x18\x06 \x01(\t\"\xb3\x01\n\x11\x41pplicationOutput\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x18\n\x10\x61pplication_name\x18\x02 \x01(\t\x12K\n\x06output\x18\x03 \x01(\x0b\x32;.oak9.tython.aws.kinesisanalyticsv2.ApplicationOutputOutput\"\x96\x01\n*ApplicationReferenceDataSourceRecordColumn\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0f\n\x07mapping\x18\x02 \x01(\t\x12\x10\n\x08sql_type\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\"\x87\x01\n3ApplicationReferenceDataSourceJSONMappingParameters\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x17\n\x0frecord_row_path\x18\x02 \x01(\t\"\xac\x01\n2ApplicationReferenceDataSourceCSVMappingParameters\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1c\n\x14record_row_delimiter\x18\x02 \x01(\t\x12\x1f\n\x17record_column_delimiter\x18\x03 \x01(\t\"\xdd\x02\n/ApplicationReferenceDataSourceMappingParameters\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12x\n\x17json_mapping_parameters\x18\x02 \x01(\x0b\x32W.oak9.tython.aws.kinesisanalyticsv2.ApplicationReferenceDataSourceJSONMappingParameters\x12w\n\x17\x63s_v_mapping_parameters\x18\x03 \x01(\x0b\x32V.oak9.tython.aws.kinesisanalyticsv2.ApplicationReferenceDataSourceCSVMappingParameters\"\xf2\x01\n*ApplicationReferenceDataSourceRecordFormat\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12o\n\x12mapping_parameters\x18\x02 \x01(\x0b\x32S.oak9.tython.aws.kinesisanalyticsv2.ApplicationReferenceDataSourceMappingParameters\x12\x1a\n\x12record_format_type\x18\x03 \x01(\t\"\xd0\x02\n-ApplicationReferenceDataSourceReferenceSchema\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x17\n\x0frecord_encoding\x18\x02 \x01(\t\x12\x66\n\x0erecord_columns\x18\x03 \x03(\x0b\x32N.oak9.tython.aws.kinesisanalyticsv2.ApplicationReferenceDataSourceRecordColumn\x12\x65\n\rrecord_format\x18\x04 \x01(\x0b\x32N.oak9.tython.aws.kinesisanalyticsv2.ApplicationReferenceDataSourceRecordFormat\"\x94\x01\n3ApplicationReferenceDataSourceS3ReferenceDataSource\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x12\n\nbucket_arn\x18\x02 \x01(\t\x12\x10\n\x08\x66ile_key\x18\x03 \x01(\t\"\xe8\x02\n1ApplicationReferenceDataSourceReferenceDataSource\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12k\n\x10reference_schema\x18\x02 \x01(\x0b\x32Q.oak9.tython.aws.kinesisanalyticsv2.ApplicationReferenceDataSourceReferenceSchema\x12\x12\n\ntable_name\x18\x03 \x01(\t\x12y\n\x18s3_reference_data_source\x18\x04 \x01(\x0b\x32W.oak9.tython.aws.kinesisanalyticsv2.ApplicationReferenceDataSourceS3ReferenceDataSource\"\xe9\x01\n\x1e\x41pplicationReferenceDataSource\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x18\n\x10\x61pplication_name\x18\x02 \x01(\t\x12t\n\x15reference_data_source\x18\x03 \x01(\x0b\x32U.oak9.tython.aws.kinesisanalyticsv2.ApplicationReferenceDataSourceReferenceDataSourceb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_kinesisanalyticsv2_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _APPLICATIONPROPERTYGROUP_PROPERTYMAPENTRY._options = None
  _APPLICATIONPROPERTYGROUP_PROPERTYMAPENTRY._serialized_options = b'8\001'
  _APPLICATION_TAGSENTRY._options = None
  _APPLICATION_TAGSENTRY._serialized_options = b'8\001'
  _APPLICATIONS3CONTENTLOCATION._serialized_start=94
  _APPLICATIONS3CONTENTLOCATION._serialized_end=243
  _APPLICATIONCODECONTENT._serialized_start=246
  _APPLICATIONCODECONTENT._serialized_end=470
  _APPLICATIONAPPLICATIONCODECONFIGURATION._serialized_start=473
  _APPLICATIONAPPLICATIONCODECONFIGURATION._serialized_end=680
  _APPLICATIONPROPERTYGROUP._serialized_start=683
  _APPLICATIONPROPERTYGROUP._serialized_end=946
  _APPLICATIONPROPERTYGROUP_PROPERTYMAPENTRY._serialized_start=896
  _APPLICATIONPROPERTYGROUP_PROPERTYMAPENTRY._serialized_end=946
  _APPLICATIONENVIRONMENTPROPERTIES._serialized_start=949
  _APPLICATIONENVIRONMENTPROPERTIES._serialized_end=1127
  _APPLICATIONCHECKPOINTCONFIGURATION._serialized_start=1130
  _APPLICATIONCHECKPOINTCONFIGURATION._serialized_end=1350
  _APPLICATIONPARALLELISMCONFIGURATION._serialized_start=1353
  _APPLICATIONPARALLELISMCONFIGURATION._serialized_end=1557
  _APPLICATIONMONITORINGCONFIGURATION._serialized_start=1560
  _APPLICATIONMONITORINGCONFIGURATION._serialized_end=1723
  _APPLICATIONFLINKAPPLICATIONCONFIGURATION._serialized_start=1726
  _APPLICATIONFLINKAPPLICATIONCONFIGURATION._serialized_end=2145
  _APPLICATIONRECORDCOLUMN._serialized_start=2148
  _APPLICATIONRECORDCOLUMN._serialized_end=2279
  _APPLICATIONJSONMAPPINGPARAMETERS._serialized_start=2281
  _APPLICATIONJSONMAPPINGPARAMETERS._serialized_end=2397
  _APPLICATIONCSVMAPPINGPARAMETERS._serialized_start=2400
  _APPLICATIONCSVMAPPINGPARAMETERS._serialized_end=2553
  _APPLICATIONMAPPINGPARAMETERS._serialized_start=2556
  _APPLICATIONMAPPINGPARAMETERS._serialized_end=2848
  _APPLICATIONRECORDFORMAT._serialized_start=2851
  _APPLICATIONRECORDFORMAT._serialized_end=3055
  _APPLICATIONINPUTSCHEMA._serialized_start=3058
  _APPLICATIONINPUTSCHEMA._serialized_end=3333
  _APPLICATIONKINESISSTREAMSINPUT._serialized_start=3335
  _APPLICATIONKINESISSTREAMSINPUT._serialized_end=3446
  _APPLICATIONKINESISFIREHOSEINPUT._serialized_start=3448
  _APPLICATIONKINESISFIREHOSEINPUT._serialized_end=3560
  _APPLICATIONINPUTLAMBDAPROCESSOR._serialized_start=3562
  _APPLICATIONINPUTLAMBDAPROCESSOR._serialized_end=3674
  _APPLICATIONINPUTPROCESSINGCONFIGURATION._serialized_start=3677
  _APPLICATIONINPUTPROCESSINGCONFIGURATION._serialized_end=3876
  _APPLICATIONINPUTPARALLELISM._serialized_start=3878
  _APPLICATIONINPUTPARALLELISM._serialized_end=3979
  _APPLICATIONINPUT._serialized_start=3982
  _APPLICATIONINPUT._serialized_end=4569
  _APPLICATIONSQLAPPLICATIONCONFIGURATION._serialized_start=4572
  _APPLICATIONSQLAPPLICATIONCONFIGURATION._serialized_end=4739
  _APPLICATIONAPPLICATIONSNAPSHOTCONFIGURATION._serialized_start=4742
  _APPLICATIONAPPLICATIONSNAPSHOTCONFIGURATION._serialized_end=4871
  _APPLICATIONAPPLICATIONCONFIGURATION._serialized_start=4874
  _APPLICATIONAPPLICATIONCONFIGURATION._serialized_end=5546
  _APPLICATION._serialized_start=5549
  _APPLICATION._serialized_end=5965
  _APPLICATION_TAGSENTRY._serialized_start=5922
  _APPLICATION_TAGSENTRY._serialized_end=5965
  _KINESISANALYTICSV2._serialized_start=5968
  _KINESISANALYTICSV2._serialized_end=6372
  _APPLICATIONCLOUDWATCHLOGGINGOPTIONCLOUDWATCHLOGGINGOPTION._serialized_start=6375
  _APPLICATIONCLOUDWATCHLOGGINGOPTIONCLOUDWATCHLOGGINGOPTION._serialized_end=6515
  _APPLICATIONCLOUDWATCHLOGGINGOPTION._serialized_start=6518
  _APPLICATIONCLOUDWATCHLOGGINGOPTION._serialized_end=6769
  _APPLICATIONOUTPUTDESTINATIONSCHEMA._serialized_start=6771
  _APPLICATIONOUTPUTDESTINATIONSCHEMA._serialized_end=6892
  _APPLICATIONOUTPUTLAMBDAOUTPUT._serialized_start=6894
  _APPLICATIONOUTPUTLAMBDAOUTPUT._serialized_end=7004
  _APPLICATIONOUTPUTKINESISFIREHOSEOUTPUT._serialized_start=7006
  _APPLICATIONOUTPUTKINESISFIREHOSEOUTPUT._serialized_end=7125
  _APPLICATIONOUTPUTKINESISSTREAMSOUTPUT._serialized_start=7127
  _APPLICATIONOUTPUTKINESISSTREAMSOUTPUT._serialized_end=7245
  _APPLICATIONOUTPUTOUTPUT._serialized_start=7248
  _APPLICATIONOUTPUTOUTPUT._serialized_end=7750
  _APPLICATIONOUTPUT._serialized_start=7753
  _APPLICATIONOUTPUT._serialized_end=7932
  _APPLICATIONREFERENCEDATASOURCERECORDCOLUMN._serialized_start=7935
  _APPLICATIONREFERENCEDATASOURCERECORDCOLUMN._serialized_end=8085
  _APPLICATIONREFERENCEDATASOURCEJSONMAPPINGPARAMETERS._serialized_start=8088
  _APPLICATIONREFERENCEDATASOURCEJSONMAPPINGPARAMETERS._serialized_end=8223
  _APPLICATIONREFERENCEDATASOURCECSVMAPPINGPARAMETERS._serialized_start=8226
  _APPLICATIONREFERENCEDATASOURCECSVMAPPINGPARAMETERS._serialized_end=8398
  _APPLICATIONREFERENCEDATASOURCEMAPPINGPARAMETERS._serialized_start=8401
  _APPLICATIONREFERENCEDATASOURCEMAPPINGPARAMETERS._serialized_end=8750
  _APPLICATIONREFERENCEDATASOURCERECORDFORMAT._serialized_start=8753
  _APPLICATIONREFERENCEDATASOURCERECORDFORMAT._serialized_end=8995
  _APPLICATIONREFERENCEDATASOURCEREFERENCESCHEMA._serialized_start=8998
  _APPLICATIONREFERENCEDATASOURCEREFERENCESCHEMA._serialized_end=9334
  _APPLICATIONREFERENCEDATASOURCES3REFERENCEDATASOURCE._serialized_start=9337
  _APPLICATIONREFERENCEDATASOURCES3REFERENCEDATASOURCE._serialized_end=9485
  _APPLICATIONREFERENCEDATASOURCEREFERENCEDATASOURCE._serialized_start=9488
  _APPLICATIONREFERENCEDATASOURCEREFERENCEDATASOURCE._serialized_end=9848
  _APPLICATIONREFERENCEDATASOURCE._serialized_start=9851
  _APPLICATIONREFERENCEDATASOURCE._serialized_end=10084
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_iam.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11gcp/gcp_iam.proto\x12\x13oak9.tython.gcp.iam\x1a\x13shared/shared.proto\"R\n IamWorkloadIdentityPoolXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xb5\x02\n\x17IamWorkloadIdentityPool\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x10\n\x08\x64isabled\x18\x02 \x01(\x08\x12\x14\n\x0c\x64isplay_name\x18\x03 \x01(\t\x12\n\n\x02id\x18\x04 \x01(\t\x12\x0c\n\x04name\x18\x05 \x01(\t\x12\x0f\n\x07project\x18\x06 \x01(\t\x12\r\n\x05state\x18\x07 \x01(\t\x12!\n\x19workload_identity_pool_id\x18\x08 \x01(\t\x12G\n\x08timeouts\x18\t \x01(\x0b\x32\x35.oak9.tython.gcp.iam.IamWorkloadIdentityPoolXTimeouts\x12\x37\n\rresource_info\x18\n \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"9\n#IamWorkloadIdentityPoolProviderXAws\x12\x12\n\naccount_id\x18\x01 \x01(\t\"U\n$IamWorkloadIdentityPoolProviderXOidc\x12\x19\n\x11\x61llowed_audiences\x18\x01 \x03(\t\x12\x12\n\nissuer_uri\x18\x02 \x01(\t\"Z\n(IamWorkloadIdentityPoolProviderXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xbe\x05\n\x1fIamWorkloadIdentityPoolProvider\x12\x1b\n\x13\x61ttribute_condition\x18\x01 \x01(\t\x12\x65\n\x11\x61ttribute_mapping\x18\x02 \x03(\x0b\x32J.oak9.tython.gcp.iam.IamWorkloadIdentityPoolProvider.AttributeMappingEntry\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x10\n\x08\x64isabled\x18\x04 \x01(\x08\x12\x14\n\x0c\x64isplay_name\x18\x05 \x01(\t\x12\n\n\x02id\x18\x06 \x01(\t\x12\x0c\n\x04name\x18\x07 \x01(\t\x12\x0f\n\x07project\x18\x08 \x01(\t\x12\r\n\x05state\x18\t \x01(\t\x12!\n\x19workload_identity_pool_id\x18\n \x01(\t\x12*\n\"workload_identity_pool_provider_id\x18\x0b \x01(\t\x12\x45\n\x03\x61ws\x18\x0c \x01(\x0b\x32\x38.oak9.tython.gcp.iam.IamWorkloadIdentityPoolProviderXAws\x12G\n\x04oidc\x18\r \x01(\x0b\x32\x39.oak9.tython.gcp.iam.IamWorkloadIdentityPoolProviderXOidc\x12O\n\x08timeouts\x18\x0e \x01(\x0b\x32=.oak9.tython.gcp.iam.IamWorkloadIdentityPoolProviderXTimeouts\x12\x37\n\rresource_info\x18\x0f \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a\x37\n\x15\x41ttributeMappingEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_iam_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _IAMWORKLOADIDENTITYPOOLPROVIDER_ATTRIBUTEMAPPINGENTRY._options = None
  _IAMWORKLOADIDENTITYPOOLPROVIDER_ATTRIBUTEMAPPINGENTRY._serialized_options = b'8\001'
  _IAMWORKLOADIDENTITYPOOLXTIMEOUTS._serialized_start=63
  _IAMWORKLOADIDENTITYPOOLXTIMEOUTS._serialized_end=145
  _IAMWORKLOADIDENTITYPOOL._serialized_start=148
  _IAMWORKLOADIDENTITYPOOL._serialized_end=457
  _IAMWORKLOADIDENTITYPOOLPROVIDERXAWS._serialized_start=459
  _IAMWORKLOADIDENTITYPOOLPROVIDERXAWS._serialized_end=516
  _IAMWORKLOADIDENTITYPOOLPROVIDERXOIDC._serialized_start=518
  _IAMWORKLOADIDENTITYPOOLPROVIDERXOIDC._serialized_end=603
  _IAMWORKLOADIDENTITYPOOLPROVIDERXTIMEOUTS._serialized_start=605
  _IAMWORKLOADIDENTITYPOOLPROVIDERXTIMEOUTS._serialized_end=695
  _IAMWORKLOADIDENTITYPOOLPROVIDER._serialized_start=698
  _IAMWORKLOADIDENTITYPOOLPROVIDER._serialized_end=1400
  _IAMWORKLOADIDENTITYPOOLPROVIDER_ATTRIBUTEMAPPINGENTRY._serialized_start=1345
  _IAMWORKLOADIDENTITYPOOLPROVIDER_ATTRIBUTEMAPPINGENTRY._serialized_end=1400
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class ArtifactRegistryRepositoryXMavenConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ALLOW_SNAPSHOT_OVERWRITES_FIELD_NUMBER: builtins.int
    VERSION_POLICY_FIELD_NUMBER: builtins.int
    allow_snapshot_overwrites: builtins.bool
    version_policy: builtins.str
    def __init__(
        self,
        *,
        allow_snapshot_overwrites: builtins.bool = ...,
        version_policy: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["allow_snapshot_overwrites", b"allow_snapshot_overwrites", "version_policy", b"version_policy"]) -> None: ...

global___ArtifactRegistryRepositoryXMavenConfig = ArtifactRegistryRepositoryXMavenConfig

@typing_extensions.final
class ArtifactRegistryRepositoryXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___ArtifactRegistryRepositoryXTimeouts = ArtifactRegistryRepositoryXTimeouts

@typing_extensions.final
class ArtifactRegistryRepository(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    CREATE_TIME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    FORMAT_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    KMS_KEY_NAME_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    REPOSITORY_ID_FIELD_NUMBER: builtins.int
    UPDATE_TIME_FIELD_NUMBER: builtins.int
    MAVEN_CONFIG_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    create_time: builtins.str
    description: builtins.str
    format: builtins.str
    id: builtins.str
    kms_key_name: builtins.str
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    location: builtins.str
    name: builtins.str
    project: builtins.str
    repository_id: builtins.str
    update_time: builtins.str
    @property
    def maven_config(self) -> global___ArtifactRegistryRepositoryXMavenConfig: ...
    @property
    def timeouts(self) -> global___ArtifactRegistryRepositoryXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        create_time: builtins.str = ...,
        description: builtins.str = ...,
        format: builtins.str = ...,
        id: builtins.str = ...,
        kms_key_name: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        repository_id: builtins.str = ...,
        update_time: builtins.str = ...,
        maven_config: global___ArtifactRegistryRepositoryXMavenConfig | None = ...,
        timeouts: global___ArtifactRegistryRepositoryXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["maven_config", b"maven_config", "resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["create_time", b"create_time", "description", b"description", "format", b"format", "id", b"id", "kms_key_name", b"kms_key_name", "labels", b"labels", "location", b"location", "maven_config", b"maven_config", "name", b"name", "project", b"project", "repository_id", b"repository_id", "resource_info", b"resource_info", "timeouts", b"timeouts", "update_time", b"update_time"]) -> None: ...

global___ArtifactRegistryRepository = ArtifactRegistryRepository

@typing_extensions.final
class ArtifactRegistryRepositoryIamBindingXCondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    EXPRESSION_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    description: builtins.str
    expression: builtins.str
    title: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        expression: builtins.str = ...,
        title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "expression", b"expression", "title", b"title"]) -> None: ...

global___ArtifactRegistryRepositoryIamBindingXCondition = ArtifactRegistryRepositoryIamBindingXCondition

@typing_extensions.final
class ArtifactRegistryRepositoryIamBinding(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    MEMBERS_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    REPOSITORY_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    CONDITION_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    etag: builtins.str
    id: builtins.str
    location: builtins.str
    @property
    def members(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    project: builtins.str
    repository: builtins.str
    role: builtins.str
    @property
    def condition(self) -> global___ArtifactRegistryRepositoryIamBindingXCondition: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        location: builtins.str = ...,
        members: collections.abc.Iterable[builtins.str] | None = ...,
        project: builtins.str = ...,
        repository: builtins.str = ...,
        role: builtins.str = ...,
        condition: global___ArtifactRegistryRepositoryIamBindingXCondition | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["condition", b"condition", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["condition", b"condition", "etag", b"etag", "id", b"id", "location", b"location", "members", b"members", "project", b"project", "repository", b"repository", "resource_info", b"resource_info", "role", b"role"]) -> None: ...

global___ArtifactRegistryRepositoryIamBinding = ArtifactRegistryRepositoryIamBinding

@typing_extensions.final
class ArtifactRegistryRepositoryIamMemberXCondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    EXPRESSION_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    description: builtins.str
    expression: builtins.str
    title: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        expression: builtins.str = ...,
        title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "expression", b"expression", "title", b"title"]) -> None: ...

global___ArtifactRegistryRepositoryIamMemberXCondition = ArtifactRegistryRepositoryIamMemberXCondition

@typing_extensions.final
class ArtifactRegistryRepositoryIamMember(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    MEMBER_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    REPOSITORY_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    CONDITION_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    etag: builtins.str
    id: builtins.str
    location: builtins.str
    member: builtins.str
    project: builtins.str
    repository: builtins.str
    role: builtins.str
    @property
    def condition(self) -> global___ArtifactRegistryRepositoryIamMemberXCondition: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        location: builtins.str = ...,
        member: builtins.str = ...,
        project: builtins.str = ...,
        repository: builtins.str = ...,
        role: builtins.str = ...,
        condition: global___ArtifactRegistryRepositoryIamMemberXCondition | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["condition", b"condition", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["condition", b"condition", "etag", b"etag", "id", b"id", "location", b"location", "member", b"member", "project", b"project", "repository", b"repository", "resource_info", b"resource_info", "role", b"role"]) -> None: ...

global___ArtifactRegistryRepositoryIamMember = ArtifactRegistryRepositoryIamMember

@typing_extensions.final
class ArtifactRegistryRepositoryIamPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    POLICY_DATA_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    REPOSITORY_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    etag: builtins.str
    id: builtins.str
    location: builtins.str
    policy_data: builtins.str
    project: builtins.str
    repository: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        location: builtins.str = ...,
        policy_data: builtins.str = ...,
        project: builtins.str = ...,
        repository: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["etag", b"etag", "id", b"id", "location", b"location", "policy_data", b"policy_data", "project", b"project", "repository", b"repository", "resource_info", b"resource_info"]) -> None: ...

global___ArtifactRegistryRepositoryIamPolicy = ArtifactRegistryRepositoryIamPolicy



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class CustomerGatewayAssociation(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    GLOBAL_NETWORK_ID_FIELD_NUMBER: builtins.int
    CUSTOMER_GATEWAY_ARN_FIELD_NUMBER: builtins.int
    DEVICE_ID_FIELD_NUMBER: builtins.int
    LINK_ID_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    global_network_id: builtins.str
    customer_gateway_arn: builtins.str
    device_id: builtins.str
    link_id: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        global_network_id: builtins.str = ...,
        customer_gateway_arn: builtins.str = ...,
        device_id: builtins.str = ...,
        link_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["customer_gateway_arn", b"customer_gateway_arn", "device_id", b"device_id", "global_network_id", b"global_network_id", "link_id", b"link_id", "resource_info", b"resource_info"]) -> None: ...

global___CustomerGatewayAssociation = CustomerGatewayAssociation

@typing_extensions.final
class NetworkManager(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CUSTOMER_GATEWAY_ASSOCIATION_FIELD_NUMBER: builtins.int
    DEVICE_FIELD_NUMBER: builtins.int
    GLOBAL_NETWORK_FIELD_NUMBER: builtins.int
    LINK_FIELD_NUMBER: builtins.int
    LINK_ASSOCIATION_FIELD_NUMBER: builtins.int
    SITE_FIELD_NUMBER: builtins.int
    TRANSIT_GATEWAY_REGISTRATION_FIELD_NUMBER: builtins.int
    @property
    def customer_gateway_association(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___CustomerGatewayAssociation]: ...
    @property
    def device(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Device]: ...
    @property
    def global_network(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___GlobalNetwork]: ...
    @property
    def link(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Link]: ...
    @property
    def link_association(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___LinkAssociation]: ...
    @property
    def site(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Site]: ...
    @property
    def transit_gateway_registration(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TransitGatewayRegistration]: ...
    def __init__(
        self,
        *,
        customer_gateway_association: collections.abc.Iterable[global___CustomerGatewayAssociation] | None = ...,
        device: collections.abc.Iterable[global___Device] | None = ...,
        global_network: collections.abc.Iterable[global___GlobalNetwork] | None = ...,
        link: collections.abc.Iterable[global___Link] | None = ...,
        link_association: collections.abc.Iterable[global___LinkAssociation] | None = ...,
        site: collections.abc.Iterable[global___Site] | None = ...,
        transit_gateway_registration: collections.abc.Iterable[global___TransitGatewayRegistration] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["customer_gateway_association", b"customer_gateway_association", "device", b"device", "global_network", b"global_network", "link", b"link", "link_association", b"link_association", "site", b"site", "transit_gateway_registration", b"transit_gateway_registration"]) -> None: ...

global___NetworkManager = NetworkManager

@typing_extensions.final
class DeviceLocation(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ADDRESS_FIELD_NUMBER: builtins.int
    LATITUDE_FIELD_NUMBER: builtins.int
    LONGITUDE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    address: builtins.str
    latitude: builtins.str
    longitude: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        address: builtins.str = ...,
        latitude: builtins.str = ...,
        longitude: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["address", b"address", "latitude", b"latitude", "longitude", b"longitude", "resource_info", b"resource_info"]) -> None: ...

global___DeviceLocation = DeviceLocation

@typing_extensions.final
class Device(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    GLOBAL_NETWORK_ID_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    MODEL_FIELD_NUMBER: builtins.int
    SERIAL_NUMBER_FIELD_NUMBER: builtins.int
    SITE_ID_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    VENDOR_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    description: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    global_network_id: builtins.str
    @property
    def location(self) -> global___DeviceLocation: ...
    model: builtins.str
    serial_number: builtins.str
    site_id: builtins.str
    type: builtins.str
    vendor: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        description: builtins.str = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        global_network_id: builtins.str = ...,
        location: global___DeviceLocation | None = ...,
        model: builtins.str = ...,
        serial_number: builtins.str = ...,
        site_id: builtins.str = ...,
        type: builtins.str = ...,
        vendor: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["location", b"location", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "global_network_id", b"global_network_id", "location", b"location", "model", b"model", "resource_info", b"resource_info", "serial_number", b"serial_number", "site_id", b"site_id", "tags", b"tags", "type", b"type", "vendor", b"vendor"]) -> None: ...

global___Device = Device

@typing_extensions.final
class GlobalNetwork(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    description: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        description: builtins.str = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "resource_info", b"resource_info", "tags", b"tags"]) -> None: ...

global___GlobalNetwork = GlobalNetwork

@typing_extensions.final
class LinkBandwidth(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DOWNLOAD_SPEED_FIELD_NUMBER: builtins.int
    UPLOAD_SPEED_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    download_speed: builtins.int
    upload_speed: builtins.int
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        download_speed: builtins.int = ...,
        upload_speed: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["download_speed", b"download_speed", "resource_info", b"resource_info", "upload_speed", b"upload_speed"]) -> None: ...

global___LinkBandwidth = LinkBandwidth

@typing_extensions.final
class Link(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    GLOBAL_NETWORK_ID_FIELD_NUMBER: builtins.int
    SITE_ID_FIELD_NUMBER: builtins.int
    BANDWIDTH_FIELD_NUMBER: builtins.int
    PROVIDER_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    global_network_id: builtins.str
    site_id: builtins.str
    @property
    def bandwidth(self) -> global___LinkBandwidth: ...
    provider: builtins.str
    description: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    type: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        global_network_id: builtins.str = ...,
        site_id: builtins.str = ...,
        bandwidth: global___LinkBandwidth | None = ...,
        provider: builtins.str = ...,
        description: builtins.str = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        type: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["bandwidth", b"bandwidth", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["bandwidth", b"bandwidth", "description", b"description", "global_network_id", b"global_network_id", "provider", b"provider", "resource_info", b"resource_info", "site_id", b"site_id", "tags", b"tags", "type", b"type"]) -> None: ...

global___Link = Link

@typing_extensions.final
class LinkAssociation(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    GLOBAL_NETWORK_ID_FIELD_NUMBER: builtins.int
    DEVICE_ID_FIELD_NUMBER: builtins.int
    LINK_ID_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    global_network_id: builtins.str
    device_id: builtins.str
    link_id: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        global_network_id: builtins.str = ...,
        device_id: builtins.str = ...,
        link_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["device_id", b"device_id", "global_network_id", b"global_network_id", "link_id", b"link_id", "resource_info", b"resource_info"]) -> None: ...

global___LinkAssociation = LinkAssociation

@typing_extensions.final
class SiteLocation(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ADDRESS_FIELD_NUMBER: builtins.int
    LATITUDE_FIELD_NUMBER: builtins.int
    LONGITUDE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    address: builtins.str
    latitude: builtins.str
    longitude: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        address: builtins.str = ...,
        latitude: builtins.str = ...,
        longitude: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["address", b"address", "latitude", b"latitude", "longitude", b"longitude", "resource_info", b"resource_info"]) -> None: ...

global___SiteLocation = SiteLocation

@typing_extensions.final
class Site(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    GLOBAL_NETWORK_ID_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    description: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    global_network_id: builtins.str
    @property
    def location(self) -> global___SiteLocation: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        description: builtins.str = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        global_network_id: builtins.str = ...,
        location: global___SiteLocation | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["location", b"location", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "global_network_id", b"global_network_id", "location", b"location", "resource_info", b"resource_info", "tags", b"tags"]) -> None: ...

global___Site = Site

@typing_extensions.final
class TransitGatewayRegistration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    GLOBAL_NETWORK_ID_FIELD_NUMBER: builtins.int
    TRANSIT_GATEWAY_ARN_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    global_network_id: builtins.str
    transit_gateway_arn: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        global_network_id: builtins.str = ...,
        transit_gateway_arn: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["global_network_id", b"global_network_id", "resource_info", b"resource_info", "transit_gateway_arn", b"transit_gateway_arn"]) -> None: ...

global___TransitGatewayRegistration = TransitGatewayRegistration



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: kubernetes/kubernetes_io.k8s.api.batch.v1.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2
from oak9.tython.models.kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta import v1_pb2 as kubernetes_dot_kubernetes__io_dot_k8s_dot_apimachinery_dot_pkg_dot_apis_dot_meta_dot_v1__pb2
from oak9.tython.models.kubernetes.kubernetes_io.k8s.api.core import v1_pb2 as kubernetes_dot_kubernetes__io_dot_k8s_dot_api_dot_core_dot_v1__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/kubernetes/kubernetes_io.k8s.api.batch.v1.proto\x12\x1coak9.tython.k8s.api.batch.v1\x1a\x13shared/shared.proto\x1a@kubernetes/kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1.proto\x1a.kubernetes/kubernetes_io.k8s.api.core.v1.proto\"\xa8\x02\n\x07\x43ronJob\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x0c\n\x04kind\x18\x02 \x01(\t\x12K\n\x08metadata\x18\x03 \x01(\x0b\x32\x39.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12\x37\n\x04spec\x18\x04 \x01(\x0b\x32).oak9.tython.k8s.api.batch.v1.CronJobSpec\x12;\n\x06status\x18\x05 \x01(\x0b\x32+.oak9.tython.k8s.api.batch.v1.CronJobStatus\x12\x37\n\rresource_info\x18\x06 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xea\x01\n\x0b\x43ronJobList\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x34\n\x05items\x18\x02 \x03(\x0b\x32%.oak9.tython.k8s.api.batch.v1.CronJob\x12\x0c\n\x04kind\x18\x03 \x01(\t\x12I\n\x08metadata\x18\x04 \x01(\x0b\x32\x37.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ListMeta\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xca\x02\n\x0b\x43ronJobSpec\x12\x1a\n\x12\x63oncurrency_policy\x18\x01 \x01(\t\x12!\n\x19\x66\x61iled_jobs_history_limit\x18\x02 \x01(\x05\x12\x43\n\x0cjob_template\x18\x03 \x01(\x0b\x32-.oak9.tython.k8s.api.batch.v1.JobTemplateSpec\x12\x10\n\x08schedule\x18\x04 \x01(\t\x12!\n\x19starting_deadline_seconds\x18\x05 \x01(\x05\x12%\n\x1dsuccessful_jobs_history_limit\x18\x06 \x01(\x05\x12\x0f\n\x07suspend\x18\x07 \x01(\x08\x12\x11\n\ttime_zone\x18\x08 \x01(\t\x12\x37\n\rresource_info\x18\t \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xaa\x02\n\rCronJobStatus\x12<\n\x06\x61\x63tive\x18\x01 \x03(\x0b\x32,.oak9.tython.k8s.api.core.v1.ObjectReference\x12O\n\x12last_schedule_time\x18\x02 \x01(\x0b\x32\x33.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.Time\x12Q\n\x14last_successful_time\x18\x03 \x01(\x0b\x32\x33.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.Time\x12\x37\n\rresource_info\x18\x04 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x9c\x02\n\x03Job\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x0c\n\x04kind\x18\x02 \x01(\t\x12K\n\x08metadata\x18\x03 \x01(\x0b\x32\x39.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12\x33\n\x04spec\x18\x04 \x01(\x0b\x32%.oak9.tython.k8s.api.batch.v1.JobSpec\x12\x37\n\x06status\x18\x05 \x01(\x0b\x32\'.oak9.tython.k8s.api.batch.v1.JobStatus\x12\x37\n\rresource_info\x18\x06 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xa7\x02\n\x0cJobCondition\x12L\n\x0flast_probe_time\x18\x01 \x01(\x0b\x32\x33.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.Time\x12Q\n\x14last_transition_time\x18\x02 \x01(\x0b\x32\x33.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.Time\x12\x0f\n\x07message\x18\x03 \x01(\t\x12\x0e\n\x06reason\x18\x04 \x01(\t\x12\x0e\n\x06status\x18\x05 \x01(\t\x12\x0c\n\x04type\x18\x06 \x01(\t\x12\x37\n\rresource_info\x18\x07 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xe2\x01\n\x07JobList\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x30\n\x05items\x18\x02 \x03(\x0b\x32!.oak9.tython.k8s.api.batch.v1.Job\x12\x0c\n\x04kind\x18\x03 \x01(\t\x12I\n\x08metadata\x18\x04 \x01(\x0b\x32\x37.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ListMeta\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xe7\x03\n\x07JobSpec\x12\x1f\n\x17\x61\x63tive_deadline_seconds\x18\x01 \x01(\x05\x12\x15\n\rbackoff_limit\x18\x02 \x01(\x05\x12\x17\n\x0f\x63ompletion_mode\x18\x03 \x01(\t\x12\x13\n\x0b\x63ompletions\x18\x04 \x01(\x05\x12\x17\n\x0fmanual_selector\x18\x05 \x01(\x08\x12\x13\n\x0bparallelism\x18\x06 \x01(\x05\x12J\n\x12pod_failure_policy\x18\x07 \x01(\x0b\x32..oak9.tython.k8s.api.batch.v1.PodFailurePolicy\x12N\n\x08selector\x18\x08 \x01(\x0b\x32<.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.LabelSelector\x12\x0f\n\x07suspend\x18\t \x01(\x08\x12>\n\x08template\x18\n \x01(\x0b\x32,.oak9.tython.k8s.api.core.v1.PodTemplateSpec\x12\"\n\x1attl_seconds_after_finished\x18\x0b \x01(\x05\x12\x37\n\rresource_info\x18\x0c \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xd2\x03\n\tJobStatus\x12\x0e\n\x06\x61\x63tive\x18\x01 \x01(\x05\x12\x19\n\x11\x63ompleted_indexes\x18\x02 \x01(\t\x12L\n\x0f\x63ompletion_time\x18\x03 \x01(\x0b\x32\x33.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.Time\x12>\n\nconditions\x18\x04 \x03(\x0b\x32*.oak9.tython.k8s.api.batch.v1.JobCondition\x12\x0e\n\x06\x66\x61iled\x18\x05 \x01(\x05\x12\r\n\x05ready\x18\x06 \x01(\x05\x12G\n\nstart_time\x18\x07 \x01(\x0b\x32\x33.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.Time\x12\x11\n\tsucceeded\x18\x08 \x01(\x05\x12X\n\x19uncounted_terminated_pods\x18\t \x01(\x0b\x32\x35.oak9.tython.k8s.api.batch.v1.UncountedTerminatedPods\x12\x37\n\rresource_info\x18\n \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xcc\x01\n\x0fJobTemplateSpec\x12K\n\x08metadata\x18\x01 \x01(\x0b\x32\x39.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12\x33\n\x04spec\x18\x02 \x01(\x0b\x32%.oak9.tython.k8s.api.batch.v1.JobSpec\x12\x37\n\rresource_info\x18\x03 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x8e\x01\n\x10PodFailurePolicy\x12\x41\n\x05rules\x18\x01 \x03(\x0b\x32\x32.oak9.tython.k8s.api.batch.v1.PodFailurePolicyRule\x12\x37\n\rresource_info\x18\x02 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x9b\x01\n&PodFailurePolicyOnExitCodesRequirement\x12\x16\n\x0e\x63ontainer_name\x18\x01 \x01(\t\x12\x10\n\x08operator\x18\x02 \x01(\t\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x37\n\rresource_info\x18\x04 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x7f\n&PodFailurePolicyOnPodConditionsPattern\x12\x0e\n\x06status\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\t\x12\x37\n\rresource_info\x18\x03 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x9d\x02\n\x14PodFailurePolicyRule\x12\x0e\n\x06\x61\x63tion\x18\x01 \x01(\t\x12[\n\ron_exit_codes\x18\x02 \x01(\x0b\x32\x44.oak9.tython.k8s.api.batch.v1.PodFailurePolicyOnExitCodesRequirement\x12_\n\x11on_pod_conditions\x18\x03 \x03(\x0b\x32\x44.oak9.tython.k8s.api.batch.v1.PodFailurePolicyOnPodConditionsPattern\x12\x37\n\rresource_info\x18\x04 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"u\n\x17UncountedTerminatedPods\x12\x0e\n\x06\x66\x61iled\x18\x01 \x03(\t\x12\x11\n\tsucceeded\x18\x02 \x03(\t\x12\x37\n\rresource_info\x18\x03 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'kubernetes.kubernetes_io.k8s.api.batch.v1_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _CRONJOB._serialized_start=217
  _CRONJOB._serialized_end=513
  _CRONJOBLIST._serialized_start=516
  _CRONJOBLIST._serialized_end=750
  _CRONJOBSPEC._serialized_start=753
  _CRONJOBSPEC._serialized_end=1083
  _CRONJOBSTATUS._serialized_start=1086
  _CRONJOBSTATUS._serialized_end=1384
  _JOB._serialized_start=1387
  _JOB._serialized_end=1671
  _JOBCONDITION._serialized_start=1674
  _JOBCONDITION._serialized_end=1969
  _JOBLIST._serialized_start=1972
  _JOBLIST._serialized_end=2198
  _JOBSPEC._serialized_start=2201
  _JOBSPEC._serialized_end=2688
  _JOBSTATUS._serialized_start=2691
  _JOBSTATUS._serialized_end=3157
  _JOBTEMPLATESPEC._serialized_start=3160
  _JOBTEMPLATESPEC._serialized_end=3364
  _PODFAILUREPOLICY._serialized_start=3367
  _PODFAILUREPOLICY._serialized_end=3509
  _PODFAILUREPOLICYONEXITCODESREQUIREMENT._serialized_start=3512
  _PODFAILUREPOLICYONEXITCODESREQUIREMENT._serialized_end=3667
  _PODFAILUREPOLICYONPODCONDITIONSPATTERN._serialized_start=3669
  _PODFAILUREPOLICYONPODCONDITIONSPATTERN._serialized_end=3796
  _PODFAILUREPOLICYRULE._serialized_start=3799
  _PODFAILUREPOLICYRULE._serialized_end=4084
  _UNCOUNTEDTERMINATEDPODS._serialized_start=4086
  _UNCOUNTEDTERMINATEDPODS._serialized_end=4203
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_google_certificate_manager_bundle.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2
from oak9.tython.models.gcp import gcp_certificate_pb2 as gcp_dot_gcp__certificate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/gcp/gcp_google_certificate_manager_bundle.proto\x12\x31oak9.tython.gcp.google_certificate_manager_bundle\x1a\x13shared/shared.proto\x1a\x19gcp/gcp_certificate.proto\"\xd2\x03\n\x18GoogleCertificateManager\x12\x63\n\x1f\x63\x65rtificate_manager_certificate\x18\x01 \x03(\x0b\x32:.oak9.tython.gcp.certificate.CertificateManagerCertificate\x12j\n#certificate_manager_certificate_map\x18\x02 \x01(\x0b\x32=.oak9.tython.gcp.certificate.CertificateManagerCertificateMap\x12u\n)certificate_manager_certificate_map_entry\x18\x03 \x03(\x0b\x32\x42.oak9.tython.gcp.certificate.CertificateManagerCertificateMapEntry\x12n\n%certificate_manager_dns_authorization\x18\x04 \x03(\x0b\x32?.oak9.tython.gcp.certificate.CertificateManagerDnsAuthorizationb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_google_certificate_manager_bundle_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _GOOGLECERTIFICATEMANAGER._serialized_start=151
  _GOOGLECERTIFICATEMANAGER._serialized_end=617
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class Certificate(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    CERTIFICATE_IDENTIFIER_FIELD_NUMBER: builtins.int
    CERTIFICATE_PEM_FIELD_NUMBER: builtins.int
    CERTIFICATE_WALLET_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    certificate_identifier: builtins.str
    certificate_pem: builtins.str
    certificate_wallet: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        certificate_identifier: builtins.str = ...,
        certificate_pem: builtins.str = ...,
        certificate_wallet: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["certificate_identifier", b"certificate_identifier", "certificate_pem", b"certificate_pem", "certificate_wallet", b"certificate_wallet", "resource_info", b"resource_info"]) -> None: ...

global___Certificate = Certificate

@typing_extensions.final
class DMS(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CERTIFICATE_FIELD_NUMBER: builtins.int
    ENDPOINT_FIELD_NUMBER: builtins.int
    EVENT_SUBSCRIPTION_FIELD_NUMBER: builtins.int
    REPLICATION_INSTANCE_FIELD_NUMBER: builtins.int
    REPLICATION_SUBNET_GROUP_FIELD_NUMBER: builtins.int
    REPLICATION_TASK_FIELD_NUMBER: builtins.int
    @property
    def certificate(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Certificate]: ...
    @property
    def endpoint(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Endpoint]: ...
    @property
    def event_subscription(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___EventSubscription]: ...
    @property
    def replication_instance(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ReplicationInstance]: ...
    @property
    def replication_subnet_group(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ReplicationSubnetGroup]: ...
    @property
    def replication_task(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ReplicationTask]: ...
    def __init__(
        self,
        *,
        certificate: collections.abc.Iterable[global___Certificate] | None = ...,
        endpoint: collections.abc.Iterable[global___Endpoint] | None = ...,
        event_subscription: collections.abc.Iterable[global___EventSubscription] | None = ...,
        replication_instance: collections.abc.Iterable[global___ReplicationInstance] | None = ...,
        replication_subnet_group: collections.abc.Iterable[global___ReplicationSubnetGroup] | None = ...,
        replication_task: collections.abc.Iterable[global___ReplicationTask] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["certificate", b"certificate", "endpoint", b"endpoint", "event_subscription", b"event_subscription", "replication_instance", b"replication_instance", "replication_subnet_group", b"replication_subnet_group", "replication_task", b"replication_task"]) -> None: ...

global___DMS = DMS

@typing_extensions.final
class EndpointKafkaSettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    BROKER_FIELD_NUMBER: builtins.int
    TOPIC_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    broker: builtins.str
    topic: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        broker: builtins.str = ...,
        topic: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["broker", b"broker", "resource_info", b"resource_info", "topic", b"topic"]) -> None: ...

global___EndpointKafkaSettings = EndpointKafkaSettings

@typing_extensions.final
class EndpointNeptuneSettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    MAX_RETRY_COUNT_FIELD_NUMBER: builtins.int
    MAX_FILE_SIZE_FIELD_NUMBER: builtins.int
    S3_BUCKET_FOLDER_FIELD_NUMBER: builtins.int
    ERROR_RETRY_DURATION_FIELD_NUMBER: builtins.int
    IAM_AUTH_ENABLED_FIELD_NUMBER: builtins.int
    S3_BUCKET_NAME_FIELD_NUMBER: builtins.int
    SERVICE_ACCESS_ROLE_ARN_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    max_retry_count: builtins.int
    max_file_size: builtins.int
    s3_bucket_folder: builtins.str
    error_retry_duration: builtins.int
    iam_auth_enabled: builtins.bool
    s3_bucket_name: builtins.str
    service_access_role_arn: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        max_retry_count: builtins.int = ...,
        max_file_size: builtins.int = ...,
        s3_bucket_folder: builtins.str = ...,
        error_retry_duration: builtins.int = ...,
        iam_auth_enabled: builtins.bool = ...,
        s3_bucket_name: builtins.str = ...,
        service_access_role_arn: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["error_retry_duration", b"error_retry_duration", "iam_auth_enabled", b"iam_auth_enabled", "max_file_size", b"max_file_size", "max_retry_count", b"max_retry_count", "resource_info", b"resource_info", "s3_bucket_folder", b"s3_bucket_folder", "s3_bucket_name", b"s3_bucket_name", "service_access_role_arn", b"service_access_role_arn"]) -> None: ...

global___EndpointNeptuneSettings = EndpointNeptuneSettings

@typing_extensions.final
class EndpointElasticsearchSettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ENDPOINT_URI_FIELD_NUMBER: builtins.int
    FULL_LOAD_ERROR_PERCENTAGE_FIELD_NUMBER: builtins.int
    ERROR_RETRY_DURATION_FIELD_NUMBER: builtins.int
    SERVICE_ACCESS_ROLE_ARN_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    endpoint_uri: builtins.str
    full_load_error_percentage: builtins.int
    error_retry_duration: builtins.int
    service_access_role_arn: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        endpoint_uri: builtins.str = ...,
        full_load_error_percentage: builtins.int = ...,
        error_retry_duration: builtins.int = ...,
        service_access_role_arn: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["endpoint_uri", b"endpoint_uri", "error_retry_duration", b"error_retry_duration", "full_load_error_percentage", b"full_load_error_percentage", "resource_info", b"resource_info", "service_access_role_arn", b"service_access_role_arn"]) -> None: ...

global___EndpointElasticsearchSettings = EndpointElasticsearchSettings

@typing_extensions.final
class EndpointS3Settings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    EXTERNAL_TABLE_DEFINITION_FIELD_NUMBER: builtins.int
    BUCKET_NAME_FIELD_NUMBER: builtins.int
    BUCKET_FOLDER_FIELD_NUMBER: builtins.int
    CSV_ROW_DELIMITER_FIELD_NUMBER: builtins.int
    CSV_DELIMITER_FIELD_NUMBER: builtins.int
    SERVICE_ACCESS_ROLE_ARN_FIELD_NUMBER: builtins.int
    COMPRESSION_TYPE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    external_table_definition: builtins.str
    bucket_name: builtins.str
    bucket_folder: builtins.str
    csv_row_delimiter: builtins.str
    csv_delimiter: builtins.str
    service_access_role_arn: builtins.str
    compression_type: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        external_table_definition: builtins.str = ...,
        bucket_name: builtins.str = ...,
        bucket_folder: builtins.str = ...,
        csv_row_delimiter: builtins.str = ...,
        csv_delimiter: builtins.str = ...,
        service_access_role_arn: builtins.str = ...,
        compression_type: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["bucket_folder", b"bucket_folder", "bucket_name", b"bucket_name", "compression_type", b"compression_type", "csv_delimiter", b"csv_delimiter", "csv_row_delimiter", b"csv_row_delimiter", "external_table_definition", b"external_table_definition", "resource_info", b"resource_info", "service_access_role_arn", b"service_access_role_arn"]) -> None: ...

global___EndpointS3Settings = EndpointS3Settings

@typing_extensions.final
class EndpointDynamoDbSettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    SERVICE_ACCESS_ROLE_ARN_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    service_access_role_arn: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        service_access_role_arn: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "service_access_role_arn", b"service_access_role_arn"]) -> None: ...

global___EndpointDynamoDbSettings = EndpointDynamoDbSettings

@typing_extensions.final
class EndpointKinesisSettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    MESSAGE_FORMAT_FIELD_NUMBER: builtins.int
    STREAM_ARN_FIELD_NUMBER: builtins.int
    SERVICE_ACCESS_ROLE_ARN_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    message_format: builtins.str
    stream_arn: builtins.str
    service_access_role_arn: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        message_format: builtins.str = ...,
        stream_arn: builtins.str = ...,
        service_access_role_arn: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["message_format", b"message_format", "resource_info", b"resource_info", "service_access_role_arn", b"service_access_role_arn", "stream_arn", b"stream_arn"]) -> None: ...

global___EndpointKinesisSettings = EndpointKinesisSettings

@typing_extensions.final
class EndpointMongoDbSettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    AUTH_SOURCE_FIELD_NUMBER: builtins.int
    AUTH_MECHANISM_FIELD_NUMBER: builtins.int
    USERNAME_FIELD_NUMBER: builtins.int
    DOCS_TO_INVESTIGATE_FIELD_NUMBER: builtins.int
    SERVER_NAME_FIELD_NUMBER: builtins.int
    PORT_FIELD_NUMBER: builtins.int
    EXTRACT_DOC_ID_FIELD_NUMBER: builtins.int
    DATABASE_NAME_FIELD_NUMBER: builtins.int
    AUTH_TYPE_FIELD_NUMBER: builtins.int
    PASSWORD_FIELD_NUMBER: builtins.int
    NESTING_LEVEL_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    auth_source: builtins.str
    auth_mechanism: builtins.str
    username: builtins.str
    docs_to_investigate: builtins.str
    server_name: builtins.str
    port: builtins.int
    extract_doc_id: builtins.str
    database_name: builtins.str
    auth_type: builtins.str
    password: builtins.str
    nesting_level: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        auth_source: builtins.str = ...,
        auth_mechanism: builtins.str = ...,
        username: builtins.str = ...,
        docs_to_investigate: builtins.str = ...,
        server_name: builtins.str = ...,
        port: builtins.int = ...,
        extract_doc_id: builtins.str = ...,
        database_name: builtins.str = ...,
        auth_type: builtins.str = ...,
        password: builtins.str = ...,
        nesting_level: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["auth_mechanism", b"auth_mechanism", "auth_source", b"auth_source", "auth_type", b"auth_type", "database_name", b"database_name", "docs_to_investigate", b"docs_to_investigate", "extract_doc_id", b"extract_doc_id", "nesting_level", b"nesting_level", "password", b"password", "port", b"port", "resource_info", b"resource_info", "server_name", b"server_name", "username", b"username"]) -> None: ...

global___EndpointMongoDbSettings = EndpointMongoDbSettings

@typing_extensions.final
class Endpoint(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    KMS_KEY_ID_FIELD_NUMBER: builtins.int
    KAFKA_SETTINGS_FIELD_NUMBER: builtins.int
    PORT_FIELD_NUMBER: builtins.int
    DATABASE_NAME_FIELD_NUMBER: builtins.int
    NEPTUNE_SETTINGS_FIELD_NUMBER: builtins.int
    ELASTICSEARCH_SETTINGS_FIELD_NUMBER: builtins.int
    S3_SETTINGS_FIELD_NUMBER: builtins.int
    ENGINE_NAME_FIELD_NUMBER: builtins.int
    DYNAMO_DB_SETTINGS_FIELD_NUMBER: builtins.int
    KINESIS_SETTINGS_FIELD_NUMBER: builtins.int
    USERNAME_FIELD_NUMBER: builtins.int
    SSL_MODE_FIELD_NUMBER: builtins.int
    SERVER_NAME_FIELD_NUMBER: builtins.int
    EXTRA_CONNECTION_ATTRIBUTES_FIELD_NUMBER: builtins.int
    ENDPOINT_TYPE_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    ENDPOINT_IDENTIFIER_FIELD_NUMBER: builtins.int
    PASSWORD_FIELD_NUMBER: builtins.int
    CERTIFICATE_ARN_FIELD_NUMBER: builtins.int
    MONGO_DB_SETTINGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    kms_key_id: builtins.str
    @property
    def kafka_settings(self) -> global___EndpointKafkaSettings: ...
    port: builtins.int
    database_name: builtins.str
    @property
    def neptune_settings(self) -> global___EndpointNeptuneSettings: ...
    @property
    def elasticsearch_settings(self) -> global___EndpointElasticsearchSettings: ...
    @property
    def s3_settings(self) -> global___EndpointS3Settings: ...
    engine_name: builtins.str
    @property
    def dynamo_db_settings(self) -> global___EndpointDynamoDbSettings: ...
    @property
    def kinesis_settings(self) -> global___EndpointKinesisSettings: ...
    username: builtins.str
    ssl_mode: builtins.str
    server_name: builtins.str
    extra_connection_attributes: builtins.str
    endpoint_type: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    endpoint_identifier: builtins.str
    password: builtins.str
    certificate_arn: builtins.str
    @property
    def mongo_db_settings(self) -> global___EndpointMongoDbSettings: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        kms_key_id: builtins.str = ...,
        kafka_settings: global___EndpointKafkaSettings | None = ...,
        port: builtins.int = ...,
        database_name: builtins.str = ...,
        neptune_settings: global___EndpointNeptuneSettings | None = ...,
        elasticsearch_settings: global___EndpointElasticsearchSettings | None = ...,
        s3_settings: global___EndpointS3Settings | None = ...,
        engine_name: builtins.str = ...,
        dynamo_db_settings: global___EndpointDynamoDbSettings | None = ...,
        kinesis_settings: global___EndpointKinesisSettings | None = ...,
        username: builtins.str = ...,
        ssl_mode: builtins.str = ...,
        server_name: builtins.str = ...,
        extra_connection_attributes: builtins.str = ...,
        endpoint_type: builtins.str = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        endpoint_identifier: builtins.str = ...,
        password: builtins.str = ...,
        certificate_arn: builtins.str = ...,
        mongo_db_settings: global___EndpointMongoDbSettings | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["dynamo_db_settings", b"dynamo_db_settings", "elasticsearch_settings", b"elasticsearch_settings", "kafka_settings", b"kafka_settings", "kinesis_settings", b"kinesis_settings", "mongo_db_settings", b"mongo_db_settings", "neptune_settings", b"neptune_settings", "resource_info", b"resource_info", "s3_settings", b"s3_settings"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["certificate_arn", b"certificate_arn", "database_name", b"database_name", "dynamo_db_settings", b"dynamo_db_settings", "elasticsearch_settings", b"elasticsearch_settings", "endpoint_identifier", b"endpoint_identifier", "endpoint_type", b"endpoint_type", "engine_name", b"engine_name", "extra_connection_attributes", b"extra_connection_attributes", "kafka_settings", b"kafka_settings", "kinesis_settings", b"kinesis_settings", "kms_key_id", b"kms_key_id", "mongo_db_settings", b"mongo_db_settings", "neptune_settings", b"neptune_settings", "password", b"password", "port", b"port", "resource_info", b"resource_info", "s3_settings", b"s3_settings", "server_name", b"server_name", "ssl_mode", b"ssl_mode", "tags", b"tags", "username", b"username"]) -> None: ...

global___Endpoint = Endpoint

@typing_extensions.final
class EventSubscription(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    SOURCE_TYPE_FIELD_NUMBER: builtins.int
    EVENT_CATEGORIES_FIELD_NUMBER: builtins.int
    ENABLED_FIELD_NUMBER: builtins.int
    SUBSCRIPTION_NAME_FIELD_NUMBER: builtins.int
    SNS_TOPIC_ARN_FIELD_NUMBER: builtins.int
    SOURCE_IDS_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    source_type: builtins.str
    @property
    def event_categories(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    enabled: builtins.bool
    subscription_name: builtins.str
    sns_topic_arn: builtins.str
    @property
    def source_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        source_type: builtins.str = ...,
        event_categories: collections.abc.Iterable[builtins.str] | None = ...,
        enabled: builtins.bool = ...,
        subscription_name: builtins.str = ...,
        sns_topic_arn: builtins.str = ...,
        source_ids: collections.abc.Iterable[builtins.str] | None = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["enabled", b"enabled", "event_categories", b"event_categories", "resource_info", b"resource_info", "sns_topic_arn", b"sns_topic_arn", "source_ids", b"source_ids", "source_type", b"source_type", "subscription_name", b"subscription_name", "tags", b"tags"]) -> None: ...

global___EventSubscription = EventSubscription

@typing_extensions.final
class ReplicationInstance(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    REPLICATION_INSTANCE_IDENTIFIER_FIELD_NUMBER: builtins.int
    ENGINE_VERSION_FIELD_NUMBER: builtins.int
    KMS_KEY_ID_FIELD_NUMBER: builtins.int
    AVAILABILITY_ZONE_FIELD_NUMBER: builtins.int
    PREFERRED_MAINTENANCE_WINDOW_FIELD_NUMBER: builtins.int
    AUTO_MINOR_VERSION_UPGRADE_FIELD_NUMBER: builtins.int
    REPLICATION_SUBNET_GROUP_IDENTIFIER_FIELD_NUMBER: builtins.int
    ALLOCATED_STORAGE_FIELD_NUMBER: builtins.int
    VPC_SECURITY_GROUP_IDS_FIELD_NUMBER: builtins.int
    ALLOW_MAJOR_VERSION_UPGRADE_FIELD_NUMBER: builtins.int
    REPLICATION_INSTANCE_CLASS_FIELD_NUMBER: builtins.int
    PUBLICLY_ACCESSIBLE_FIELD_NUMBER: builtins.int
    MULTI_AZ_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    replication_instance_identifier: builtins.str
    engine_version: builtins.str
    kms_key_id: builtins.str
    availability_zone: builtins.str
    preferred_maintenance_window: builtins.str
    auto_minor_version_upgrade: builtins.bool
    replication_subnet_group_identifier: builtins.str
    allocated_storage: builtins.int
    @property
    def vpc_security_group_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    allow_major_version_upgrade: builtins.bool
    replication_instance_class: builtins.str
    publicly_accessible: builtins.bool
    multi_az: builtins.bool
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        replication_instance_identifier: builtins.str = ...,
        engine_version: builtins.str = ...,
        kms_key_id: builtins.str = ...,
        availability_zone: builtins.str = ...,
        preferred_maintenance_window: builtins.str = ...,
        auto_minor_version_upgrade: builtins.bool = ...,
        replication_subnet_group_identifier: builtins.str = ...,
        allocated_storage: builtins.int = ...,
        vpc_security_group_ids: collections.abc.Iterable[builtins.str] | None = ...,
        allow_major_version_upgrade: builtins.bool = ...,
        replication_instance_class: builtins.str = ...,
        publicly_accessible: builtins.bool = ...,
        multi_az: builtins.bool = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["allocated_storage", b"allocated_storage", "allow_major_version_upgrade", b"allow_major_version_upgrade", "auto_minor_version_upgrade", b"auto_minor_version_upgrade", "availability_zone", b"availability_zone", "engine_version", b"engine_version", "kms_key_id", b"kms_key_id", "multi_az", b"multi_az", "preferred_maintenance_window", b"preferred_maintenance_window", "publicly_accessible", b"publicly_accessible", "replication_instance_class", b"replication_instance_class", "replication_instance_identifier", b"replication_instance_identifier", "replication_subnet_group_identifier", b"replication_subnet_group_identifier", "resource_info", b"resource_info", "tags", b"tags", "vpc_security_group_ids", b"vpc_security_group_ids"]) -> None: ...

global___ReplicationInstance = ReplicationInstance

@typing_extensions.final
class ReplicationSubnetGroup(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    REPLICATION_SUBNET_GROUP_DESCRIPTION_FIELD_NUMBER: builtins.int
    REPLICATION_SUBNET_GROUP_IDENTIFIER_FIELD_NUMBER: builtins.int
    SUBNET_IDS_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    replication_subnet_group_description: builtins.str
    replication_subnet_group_identifier: builtins.str
    @property
    def subnet_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        replication_subnet_group_description: builtins.str = ...,
        replication_subnet_group_identifier: builtins.str = ...,
        subnet_ids: collections.abc.Iterable[builtins.str] | None = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["replication_subnet_group_description", b"replication_subnet_group_description", "replication_subnet_group_identifier", b"replication_subnet_group_identifier", "resource_info", b"resource_info", "subnet_ids", b"subnet_ids", "tags", b"tags"]) -> None: ...

global___ReplicationSubnetGroup = ReplicationSubnetGroup

@typing_extensions.final
class ReplicationTask(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    REPLICATION_TASK_SETTINGS_FIELD_NUMBER: builtins.int
    TABLE_MAPPINGS_FIELD_NUMBER: builtins.int
    CDC_START_POSITION_FIELD_NUMBER: builtins.int
    REPLICATION_TASK_IDENTIFIER_FIELD_NUMBER: builtins.int
    CDC_STOP_POSITION_FIELD_NUMBER: builtins.int
    SOURCE_ENDPOINT_ARN_FIELD_NUMBER: builtins.int
    MIGRATION_TYPE_FIELD_NUMBER: builtins.int
    TARGET_ENDPOINT_ARN_FIELD_NUMBER: builtins.int
    REPLICATION_INSTANCE_ARN_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    TASK_DATA_FIELD_NUMBER: builtins.int
    CDC_START_TIME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    replication_task_settings: builtins.str
    table_mappings: builtins.str
    cdc_start_position: builtins.str
    replication_task_identifier: builtins.str
    cdc_stop_position: builtins.str
    source_endpoint_arn: builtins.str
    migration_type: builtins.str
    target_endpoint_arn: builtins.str
    replication_instance_arn: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    task_data: builtins.str
    cdc_start_time: builtins.float
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        replication_task_settings: builtins.str = ...,
        table_mappings: builtins.str = ...,
        cdc_start_position: builtins.str = ...,
        replication_task_identifier: builtins.str = ...,
        cdc_stop_position: builtins.str = ...,
        source_endpoint_arn: builtins.str = ...,
        migration_type: builtins.str = ...,
        target_endpoint_arn: builtins.str = ...,
        replication_instance_arn: builtins.str = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        task_data: builtins.str = ...,
        cdc_start_time: builtins.float = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cdc_start_position", b"cdc_start_position", "cdc_start_time", b"cdc_start_time", "cdc_stop_position", b"cdc_stop_position", "migration_type", b"migration_type", "replication_instance_arn", b"replication_instance_arn", "replication_task_identifier", b"replication_task_identifier", "replication_task_settings", b"replication_task_settings", "resource_info", b"resource_info", "source_endpoint_arn", b"source_endpoint_arn", "table_mappings", b"table_mappings", "tags", b"tags", "target_endpoint_arn", b"target_endpoint_arn", "task_data", b"task_data"]) -> None: ...

global___ReplicationTask = ReplicationTask
